#!/usr/bin/perl

######################################################################
package Cognition::uF::RelEnclosure;
######################################################################

use XML::LibXML qw(:all);
use strict;
use CGI::Util;
use Digest::SHA1 qw(sha1_hex);

BEGIN
{
	our $VERSION = 0.1;
	our @ISA = qw(Cognition::uF);
}


sub parse_all
{
	my $page   = shift;
	my $within = shift || $page->{DOM};
	my @nodes = Cognition::HTMLParser::Utils::searchRel('enclosure', $within);
	my @rv;
	
	foreach my $t (@nodes)
	{
		my $t_parsed = parse($page, $t);
		push @rv, $t_parsed;
	}
	
	return @rv;
} #/sub parse_all


sub uri
{
	my $this = shift;
	my $all  = shift;
	my @rv;
	
	push @rv, $this->{enclosure};
	
	return $rv[0] unless (defined $all);
	while ($all) { shift @rv; $all--; }
	return @rv;
} #/sub uri


sub metadata_ns
{
	my $this = shift;
	return { 'RELENC' => { nsurl=>'http://microformats.org/wiki/rel-enclosure#',title=>'rel-enclosure' } };
} #/sub namespace


sub rdf_subject
{
	my $this    = shift;
	my $ns      = 'http://microformats.org/wiki/rel-enclosure#';

	# Create RDF subject
	my $subject = Cognition::RDFModel::Subject->new($this->uri);
	$subject->addObject($this);
	$subject->setDom($this->{_dom});

	$subject->addVal('http://www.w3.org/1999/02/22-rdf-syntax-ns#type',
		Cognition::RDFModel::Value->new($ns.'enclosure', 1));
	
	return $subject;
	
} #/sub rdf_subject


sub parse
{
	my $page = shift;
	my $rv = { '_dom'=>shift };
	my $t_node = $rv->{'_dom'}->cloneNode(1);

	my $id = $t_node->getAttribute('id');
	$rv->{_id} = $id if (length $id);
	$rv->{_page} = $page;
	
	my $enc = $page->abs_url($t_node->getAttribute('href'));
	$rv->{enclosure} = $enc;
	
	bless $rv;
	return $rv;
	
} #/sub parse


1; #/package Cognition::uF::RelEnclosure
